%define python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")
%define debug_package %{nil} 

%if 0%{?fedora} || 0%{?centos} >= 7
%global         with_python3 1
%else
%global         with_python3 0
%endif

%if 0%{?centos} == 7
%define python3_pkgversion 36
%endif

Name:		libvshadow
Version:	20191221
Release:	1%{?dist}
Summary:	Library to access the Windows NT Volume Shadow Snapshot (VSS) format
Group:		System Environment/Libraries
License:	LGPL
Source:		%{name}-alpha-%{version}.tar.gz
URL:		https://github.com/libyal/libvshadow/wiki
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:  autoconf automake pkgconfig gettext-devel libtool

%description
libvshadow is a library to access the Windows NT Volume Shadow Snapshot (VSS) format

%package devel
Summary:	Header files and libraries for developing applications for libvshadow
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
BuildRequires:	libbfio-devel

%description devel
Header files and libraries for developing applications for libvshadow.

%package tools
Summary:	Several tools for reading Windows NT Volume Shadow Snapshots (VSS)
Group:		Applications/System
Requires:	%{name} = %{version}-%{release}  fuse-libs
BuildRequires:	 fuse-devel

%description tools
Several tools for reading Windows NT Volume Shadow Snapshots (VSS)

%package python2
Summary:	Python bindings for libvshadow
Group:		System Environment/Libraries
Requires:	%{name} = %{version}-%{release} python
BuildRequires:	python2-devel
Obsoletes:	%{name}-python
Provides:	%{name}-python = %{version}

%description python2
Python bindings for libvshadow

%if 0%{?with_python3}
%package python%{python3_pkgversion}
Summary: Python 3 bindings for libvshadow
Group: System Environment/Libraries
Requires: %{name} = %{version}-%{release}
BuildRequires: python%{python3_pkgversion}
BuildRequires: python%{python3_pkgversion}-devel
BuildRequires: python%{python3_pkgversion}-setuptools

%description python%{python3_pkgversion}
Python 3 bindings for libvshadow
%endif

%prep
%setup -q

%build
if [ -f synclibs.sh ]; then sh synclibs.sh; fi
if [ -f autogen.sh  ]; then sh autogen.sh;  fi
%if 0%{?with_python3}
%configure --prefix=/usr --libdir=%{_libdir} --mandir=%{_mandir} --enable-python2 --enable-python3 
%else
%configure --prefix=/usr --libdir=%{_libdir} --mandir=%{_mandir} --enable-python
%endif
%if 0%{?rhel} == 5
sed --in-place 's/^CC.*=.*gcc$/CC = gcc -std=c99/' pyvshadow/Makefile
%endif
make %{?_smp_mflags}

%install
rm -rf ${RPM_BUILD_ROOT}
make DESTDIR=${RPM_BUILD_ROOT} install

%clean
rm -rf ${RPM_BUILD_ROOT}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc AUTHORS COPYING NEWS README
%{_libdir}/*.so.*

%files devel
%defattr(644,root,root,755)
%doc AUTHORS COPYING NEWS README ChangeLog
%{_libdir}/*.a
%{_libdir}/*.la
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/*
%{_mandir}/man3/*

%files tools
%defattr(644,root,root,755)
%doc AUTHORS COPYING NEWS README
%attr(755,root,root) %{_bindir}/vshadowinfo
%attr(755,root,root) %{_bindir}/vshadowmount
%attr(755,root,root) %{_bindir}/vshadowdebug
%{_mandir}/man1/*

%files python2
%defattr(644,root,root,755)
%doc AUTHORS COPYING NEWS README
%{_libdir}/python2*/site-packages/*.a
%{_libdir}/python2*/site-packages/*.la
%{_libdir}/python2*/site-packages/*.so

%if 0%{?with_python3}
%files python%{python3_pkgversion}
%defattr(644,root,root,755)
%doc AUTHORS COPYING NEWS README
%{_libdir}/python3*/site-packages/*.a
%{_libdir}/python3*/site-packages/*.la
%{_libdir}/python3*/site-packages/*.so
%endif

%changelog
* Sat Dec 21 2019 Lawrence R. Rogers <lrr@cert.org> 20191221-1
* Release 20191221-1
	Version 20191221

* Sun Nov  3 2019 Lawrence R. Rogers <lrr@cert.org> 20191103-1
* Release 20191103-1
	Version from 20191103.

* Sat May 18 2019 Lawrence R. Rogers <lrr@cert.org> 20190323-3
* Release 20190323-3
	Version 20190323-3: Uses python3_pkgversion for the current version of Python 3.

* Tue Apr  9 2019 Lawrence R. Rogers <lrr@cert.org> 20190323-2
* Release 20190323-2
        Release 2 - Rebuilt for Python 3.6 for CentOS/RHEL 7

* Sat Mar 23 2019 Lawrence R. Rogers <lrr@cert.org> 20190323-1
* Release 20190323-1
	Version from 20190323.

* Tue Feb 12 2019 Lawrence R. Rogers <lrr@cert.org> 20190127-3
* Release 20190127-3
	Release 3 - Removed conflicts when that arise when python2 and python3
		    versions are attempted to be installed on a system.

* Mon Jan 28 2019 Lawrence R. Rogers <lrr@cert.org> 20190127-2
* Release 20190127-2
        Version as of 20190127
	-python packages renamed to -python2

* Sun Jan 27 2019 Lawrence R. Rogers <lrr@cert.org> 20190127-1
* Release 20190127-1
	Version from 20190127.

* Sat Jan 12 2019 Lawrence R. Rogers <lrr@cert.org> 20190112-1
* Release 20190112-1
	Version from 20190112.

* Sun Dec 16 2018 Lawrence R. Rogers <lrr@cert.org> 20181216-1
* Release 20181216-1
	Version from 20181216.

* Sat Sep  2 2017 Lawrence R. Rogers <lrr@cert.org> 20170902-1
* Release 20170902-1
	Version from 20170902.

* Sat Jul 15 2017 Lawrence R. Rogers <lrr@cert.org> 20170715-1
* Release 20170715-1
	Version from 20170715.

* Fri Nov 11 2016 Lawrence R. Rogers <lrr@cert.org> 20161111-1
* Release 20161111-1
	Version from 20161111
		Added human readable volume size
		Fix for forwarder block descriptor replace
		Moved libcstring macros to common
		Updated documentation links.
		Updated project configuration.
		Worked on tests
		Worked on tests and Windows test scripts.

* Tue Jun 28 2016 Lawrence R. Rogers <lrr@cert.org> 20160110-2
* Release 20160110-2
	Adds libbfio-devel as a dependency. This was needed so that dff works correctly.

* Sun Jan 10 2016 Lawrence R. Rogers <lrr@cert.org> 20160110-1
* Release 20160110-1
	20160109
	* worked on Python 3 support
	* worked on win2k3 format support

	20160108
	* 2016 update

* Sun Dec 20 2015 Lawrence R. Rogers <lrr@cert.org> 20151220-1
* Release 20151220-1
	20151220
	* changes for deployment
	* updated dependencies

	20150905
	* updated dependencies

	20150719
	* worked on signature check

* Sun May 31 2015 Lawrence R. Rogers <lrr@cert.org> 20150106-2
* Release 20150106-2
	Libuna GCC-5 Patch

* Tue Jan  6 2015 Lawrence R. Rogers <lrr@cert.org> 20150106-1
* Release 20150106-1
	20150106
	* 2015 update

	20141223
	* worked on Python 3 support
	* worked on tests

	20141201
	* code clean up

	20141114
	* code clean up
	* worked on multi-threading support

	20141104
	* removed deprecated functions
	  - libvshadow_store_read_random
	  - pyvshadow.store.read_random

	20141027
	* changes for deployment

* Thu Oct 23 2014 Lawrence R. Rogers <lrr@cert.org> 20141023-1
* Release 20141023-1
	20141023
	* changes for deployment

	20141017
	* changes for deployment

	20140928
	* removed README.macosx
	* changes for project site move

	20140901
	* bug fix in Python-bindings
	* Code clean up

* Thu Jul 31 2014 Lawrence R. Rogers <lrr@cert.org> 20140731-1
* Release 20140731-1
	20140731
	* updated dependencies
	* worked on Python bindings

	20140531
	* updated dependencies

	20140325
	* worked on setup.py

* Sun Mar 23 2014 Joachim Metz <joachim.metz@gmail.com> 20140323-1
- Auto-generated

